==> indy-ftests-folo-0.99.1.5-sources.jar: org/commonjava/indy/folo/ftest/urls/StoreOneTrackedAndVerifyUrlInReportTest.java <==
/**
 * Copyright (C) 2011 Red Hat, Inc. (jdcasey@commonjava.org)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.commonjava.indy.folo.ftest.urls;

import static org.commonjava.indy.model.core.StoreType.hosted;
import static org.hamcrest.CoreMatchers.equalTo;
import static org.junit.Assert.assertThat;

import java.io.ByteArrayInputStream;
import java.util.Set;

import org.commonjava.indy.folo.dto.TrackedContentDTO;
import org.commonjava.indy.folo.dto.TrackedContentEntryDTO;
import org.junit.Test;

public class StoreOneTrackedAndVerifyUrlInReportTest
    extends AbstractFoloUrlsTest
{

    @Test
    public void storeOneFileAndVerifyItInParentDirectoryListing()
        throws Exception
    {
        final byte[] data = "this is a test".getBytes();
        final ByteArrayInputStream stream = new ByteArrayInputStream( data );
        final String root = "/path/to/";
        final String path = root + "foo.txt";

        final String trackingId = "tracker";

        content.store( trackingId, hosted, STORE, path, stream );

        final TrackedContentDTO report = admin.getTrackingReport( trackingId, hosted, STORE );

        final Set<TrackedContentEntryDTO> uploads = report.getUploads();
        for ( final TrackedContentEntryDTO upload : uploads )
        {
            final String uploadPath = upload.getPath();
            final String localUrl = client.content()
                                          .contentUrl( hosted, STORE, uploadPath );

            assertThat( "Incorrect local URL for upload: '" + uploadPath + "'", upload.getLocalUrl(),
                        equalTo( localUrl ) );
        }
    }

}

==> indy-ftests-folo-1.1.1-sources.jar: org/commonjava/indy/folo/ftest/urls/StoreOneTrackedAndVerifyUrlInReportTest.java <==
/**
 * Copyright (C) 2011 Red Hat, Inc. (jdcasey@commonjava.org)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.commonjava.indy.folo.ftest.urls;

import static org.commonjava.indy.model.core.StoreType.hosted;
import static org.hamcrest.CoreMatchers.equalTo;
import static org.junit.Assert.assertThat;

import java.io.ByteArrayInputStream;
import java.util.Set;

import org.commonjava.indy.folo.client.IndyFoloAdminClientModule;
import org.commonjava.indy.folo.dto.TrackedContentDTO;
import org.commonjava.indy.folo.dto.TrackedContentEntryDTO;
import org.junit.Test;

public class StoreOneTrackedAndVerifyUrlInReportTest
    extends AbstractFoloUrlsTest
{

    @Test
    public void storeOneFileAndVerifyItInParentDirectoryListing()
        throws Exception
    {
        final byte[] data = "this is a test".getBytes();
        final ByteArrayInputStream stream = new ByteArrayInputStream( data );
        final String root = "/path/to/";
        final String path = root + "foo.txt";

        final String trackingId = "tracker";

        content.store( trackingId, hosted, STORE, path, stream );

        assertThat( client.module( IndyFoloAdminClientModule.class ).sealTrackingRecord( trackingId ),
                    equalTo( true ) );

        final TrackedContentDTO report = admin.getTrackingReport( trackingId );

        final Set<TrackedContentEntryDTO> uploads = report.getUploads();
        for ( final TrackedContentEntryDTO upload : uploads )
        {
            final String uploadPath = upload.getPath();
            final String localUrl = client.content()
                                          .contentUrl( hosted, STORE, uploadPath );

            assertThat( "Incorrect local URL for upload: '" + uploadPath + "'", upload.getLocalUrl(),
                        equalTo( localUrl ) );
        }
    }

}
